@@ -77,7 +77,9 @@ class Function(YamlOrderedDict):
 
             layers.append({"Ref": "PythonRequirementsLambdaLayer"})
 
-        self._service.resources.export(self.resource_name() + "ArnOutput",  self.name.spinal + "-arn", self.arn(), append=False)
+        self._service.resources.export(
+            self.resource_name() + "ArnOutput", self.name.spinal + "-arn", self.arn(), append=False
+        )
 
         if layers:
             self.layers = layers
@@ -224,7 +226,7 @@ class Function(YamlOrderedDict):
         return self
 
     def with_idempotency(self, table_name=None):
-        table_name = table_name or f"{self.name.pascal.replace('${sls:stage}', '')}Idempotency-" + '${sls:stage}'
+        table_name = table_name or f"{self.name.pascal.replace('${sls:stage}', '')}Idempotency-" + "${sls:stage}"
 
         idempotency_table = Table(
             TableName=table_name,
